@@ -109,8 +109,8 @@ class STDOUT(Actor):
            |  Incoming events.
     '''
 
-    def __init__(self, name, size=100, frequency=1, complete=False, counter=False, prefix="", pid=False, flush=1):
-        Actor.__init__(self, name, size, frequency)
+    def __init__(self, name, complete=False, counter=False, prefix="", pid=False, flush=1, *args, **kwargs):
+        Actor.__init__(self, name, *args, **kwargs)
 
         self.complete = complete
         self.counter = counter
